OC.L10N.register(
    "mail",
    {
    "Important" : "முக்கியமான ",
    "Work" : "வேலை",
    "Personal" : "தனிப்பட்ட",
    "Name" : "பெயர்",
    "Password" : "கடவுச்சொல்",
    "None" : "ஒன்றுமில்லை",
    "Save" : "சேமிக்க ",
    "Connect" : "இணைக்க",
    "Cancel" : "இரத்து செய்க",
    "Favorite" : "விருப்பமான",
    "Select" : "Select",
    "Create" : "உருவாக்குக",
    "Choose" : "தெரிவுசெய்க ",
    "Other" : "மற்றவை",
    "Move" : "Move",
    "Quota" : "பங்கு",
    "Saving" : "Saving",
    "Refresh" : "மீள் ஏற்றுக",
    "Delete" : "நீக்குக",
    "Add" : "சேர்க்க",
    "Close" : "மூடுக",
    "Tags" : "சீட்டுகள்",
    "Search" : "Search",
    "Date" : "Date",
    "Remove" : "அகற்றுக",
    "General" : "பொதுவான",
    "User" : "User",
    "Host" : "ஓம்புனர்",
    "Port" : "துறை ",
    "Back" : "பின்னுக்கு",
    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
    "All" : "எல்லாம்",
    "Favorites" : "விருப்பங்கள்"
},
"nplurals=2; plural=(n != 1);");
